@@ -1,16 +1,15 @@
-library('TreeTools')
+library("TreeTools")
 
-if (packageVersion('graphics') < '4.1')
 test_that('TreeDistPlot works', {
   tr <- PectinateTree(1:11)
   tr$edge.width <- rep(1:2, 10)
-  Test1 <- function () {
+  Test1 <- function() {
     TreeDist::TreeDistPlot(tr, title='Test', 
                          bold = c(2, 4, 6),
                          leaveRoom = TRUE,
                          prune = 1, graft = 10)
   }
-  Test2 <- function () {
+  Test2 <- function() {
     TreeDist::TreeDistPlot(tr, title='Crop tightly', 
                            bold = c(2, 4, 6), prune = 11, graft = 10,
                            leaveRoom = FALSE)
@@ -26,16 +25,15 @@ test_that('TreeDistPlot works', {
   tr$tip.label <- LETTERS[1:11]
   vdiffr::expect_doppelganger("Test-UC-LETTERS", Test2)
   
-}) else expect_false(packageVersion('graphics') < '4.1')
+})
 
-if (packageVersion('graphics') < '4.1')
 test_that('VisualizeMatching() works', {
   tree1 <- PectinateTree(1:11)
   tree2 <- tree1
   tree2$tip.label[c(11, 1)] <- tree1$tip.label[c(1, 11)]
   tree2r <- CollapseNode(tree2, 20:21)
   
-  Minus <- function (...) {
+  Minus <- function(...) {
     x <- MutualClusteringInfo(...)
     attr(x, 'pairScores') <- -attr(x, 'pairScores')
     x
@@ -47,21 +45,21 @@ test_that('VisualizeMatching() works', {
   skip_if(packageVersion("graphics") < "4.1")
   skip_if(packageVersion("vdiffr") < "1.0")
   
-  TestVM <- function () {
+  TestVM <- function() {
     VisualizeMatching(MutualClusteringInfo, tree1, tree2, 
                       setPar = TRUE, precision = 3, matchZeros = FALSE,
                       Plot = plot.phylo)
   }
   vdiffr::expect_doppelganger('Test VM', TestVM)
   
-  TestVMr <- function () {
+  TestVMr <- function() {
     VisualizeMatching(MutualClusteringInfo, tree1, tree2r,
                       setPar = TRUE, precision = 3, matchZeros = TRUE, 
                       Plot = plot.phylo, cex = 1.5)
   }
   vdiffr::expect_doppelganger('Test VMr', TestVMr) # Unclear why this test fails on Travis. 
   
-  vdiffr::expect_doppelganger('Visualize MCI matching', function () {
+  vdiffr::expect_doppelganger('Visualize MCI matching', function() {
     par(mfrow = c(2, 2), mar = rep(0.1, 4), cex = 1.5)
     tree1 <- ape::read.tree(text='((1, 2), ((3, (4, 5)), (6, (7, (8, 9)))));')
     tree2 <- ape::read.tree(text='((1, 2), ((3, 4, (5, 9)), (6, (7, 8))));')
@@ -77,7 +75,7 @@ test_that('VisualizeMatching() works', {
                       leaveRoom = FALSE)
   })
   
-  vdiffr::expect_doppelganger('RF: Collapse a node', function () {
+  vdiffr::expect_doppelganger('RF: Collapse a node', function() {
     par(mfrow = c(2, 2), mar = rep(0.1, 4), cex = 1.5)
     tree1 <- ape::read.tree(text='((1, 2), ((6, (7, 8)), (3, 4, (5, 9))));')
     tree2 <- ape::read.tree(text='((1, 2), ((3, (4, (5, 9))), (6, (7, 8))));')
@@ -94,7 +92,7 @@ test_that('VisualizeMatching() works', {
   })
   
   
-  vdiffr::expect_doppelganger('RF: Collapse and change', function () {
+  vdiffr::expect_doppelganger('RF: Collapse and change', function() {
     par(mfrow = c(2, 2), mar = rep(0.1, 4), cex = 1.5)
     tree1 <- ape::read.tree(text='((1, 2), ((6, (7, 8)), (3, 4, (5, 9))));')
     tree2 <- ape::read.tree(text='((1, 2), ((3, (4, (5, 9))), ((6, 7), 8)));')
@@ -110,7 +108,7 @@ test_that('VisualizeMatching() works', {
                       leaveRoom = FALSE)
   })
   
-  vdiffr::expect_doppelganger('RF VM Single splits; plainEdges', function () {
+  vdiffr::expect_doppelganger('RF VM Single splits; plainEdges', function() {
     par(mfrow = c(2, 2), mar = rep(0.1, 4), cex = 1.5)
     tree1 <- ape::read.tree(text = '((1, 2), (3, 4, 5, 6, 7, 8));')
     tree2 <- ape::read.tree(text = '((1, 2, 3), (4, 5, 6, 7, 8));')
@@ -129,12 +127,35 @@ test_that('VisualizeMatching() works', {
                       leaveRoom = FALSE)
   })
   
-  vdiffr::expect_doppelganger('JRF VM matchZeros FALSE', function () {
-    JRF2 <- function (tree1, tree2, ...) 
+  vdiffr::expect_doppelganger('JRF VM matchZeros FALSE', function() {
+    JRF2 <- function(tree1, tree2, ...) 
       JaccardRobinsonFoulds(tree1, tree2, k = 2, allowConflict = FALSE, ...)
     
     tree1 <- EnforceOutgroup(as.phylo(704564, 10), paste0('t', c(1,4,5,8,9)))
     tree2 <- EnforceOutgroup(as.phylo(20165 , 10), paste0('t', c(1,4)))
     VisualizeMatching(JRF2, tree1, tree2, matchZeros = FALSE)
   })
-})
\ No newline at end of file
+})
+
+test_that("MST example plots as expected", {
+  skip_if_not_installed("graphics", "4.1")
+  skip_if_not_installed("vdiffr", "1.0")
+  skip_if_not_installed("TreeTools", "1.6.0.9008")
+  vdiffr::expect_doppelganger('MST example plot', function() {
+    set.seed(0)
+    distances <- ClusteringInfoDist(as.phylo(5:16, 8))
+    mapping <- cmdscale(distances, k = 2)
+    mstEnds <- MSTEdges(distances)
+    
+    # Set up blank plot
+    plot(mapping, asp = 1, frame.plot = FALSE, ann = FALSE, axes = FALSE,
+         type = "n")
+    # Add MST
+    MSTSegments(mapping, mstEnds, 
+                col = StrainCol(distances, mapping, mstEnds))
+    # Add points at end so they overprint the MST
+    points(mapping)
+    SpectrumLegend(legend = c("Contracted", "Median", "Extended"),
+                   palette = rev(hcl.colors(256L, "RdYlBu")))
+  })
+})
