@@ -1,4 +1,4 @@
-library('TreeTools')
+library("TreeTools", quietly = TRUE, warn.conflicts = FALSE)
 
 test_that('Tree normalization works', {
   expect_equal(0.5, NormalizeInfo(5, 3, 5, how = TRUE, 
@@ -118,7 +118,7 @@ test_that('Matches are reported', {
   splits1 <- as.Splits(tree1)
   splits2 <- as.Splits(tree2, tree1)
   
-  Test <- function (Func, relaxed = FALSE, ...) {
+  Test <- function(Func, relaxed = FALSE, ...) {
     at <- attributes(Func(tree1, tree2, reportMatching = TRUE, ...))
     expect_equal(3L, length(at))
     
@@ -186,7 +186,7 @@ test_that('Matchings are calculated in both directions', {
   splits2 <- as.Splits(tree2)
   nMatches <- min(length(splits1), length(splits2))
   
-  Test <- function (Func, ...) {
+  Test <- function(Func, ...) {
     matching12 <- Func(tree1, tree2, reportMatching = TRUE, ...)
     expect_equal(nMatches, length(attr(matching12, 'matchedSplits')))
     
@@ -226,7 +226,7 @@ test_that('.TreeDistance() supports all sizes', {
 })
 
 test_that("Unrooteds are handled by MAST", {
-  trees <- list(unroot(BalancedTree(8)), unroot(PectinateTree(8)))
+  trees <- list(UnrootTree(BalancedTree(8)), UnrootTree(PectinateTree(8)))
   expect_equal(6L, as.integer(MASTSize(trees, rooted = FALSE)),
                ignore_attr = TRUE)
 })
